@@ -1,3 +1,4 @@
+// $Id: main_thread.c,v 1.3 2005/11/08 21:29:54 khlut Exp $
 // Copyright 2005 Elphel, Inc.
 //
 // This file is part of GenReS.
@@ -250,11 +251,11 @@ NPError NP_GetValue(void *future, NPPVariable variable, void *value)
   printf("NP_GETVALUE\n");
   switch (variable) {
     case NPPVpluginNameString:
-      *((char **) value) = "The GenReS Mozilla plugin V 0.7";
+      *((char **) value) = "The GenReS Mozilla plugin V 0.7.1";
       break;
     case NPPVpluginDescriptionString:
-      *((char **) value) = "<a href=http://sourceforge.net/projects/genres/>GENeric REconfigureable Scriptable plugin</a> for Mozilla/Firefox<br>"
-    			   "Version 0.7<br>"
+      *((char **) value) = "<a href=https://savannah.nongnu.org/projects/genres>GENeric REconfigureable Scriptable plugin</a> for Mozilla/Firefox<br>"
+    			   "Version 0.7.1<br>"
 			   "Author: Sergey Khlutchin<br>"
 			   LICENSE;
       break;
