@@ -1,5 +1,5 @@
 #!/usr/bin/perl
-# $Id: mplayer.pl,v 1.2 2005/11/08 20:16:01 khlut Exp $
+# $Id: mplayer.pl,v 1.3 2005/11/11 09:33:43 khlut Exp $
 # Bind mplayer and mencoder with HTML object
 #
 # Copyright 2005 Elphel, Inc.
@@ -54,8 +54,11 @@ $v{play}=1;
 $|=1;
 my $shutstate:shared=0;
 my $pausestate:shared=0;
+my $queue:shared="";
+my $thrid:shared;
 
 sub shut{
+    lock $queue,$shutstate;
     !$shutstate++ && $v{save} && $shutstate++;
     alarm $v{quittimeout};
     if($shutstate==1){		#interrupt read
@@ -72,10 +75,15 @@ sub shut{
 
 sub normal_exit{
     $SIG{PIPE}='IGNORE';
+    lock $queue,$shutstate;
     alarm $v{$shutstate?'quittimeout':'timeout'};
     waitpid $slvp, 0;
     waitpid $slvp, 0;
     waitpid $slvp, 0;
+    if(waitpid($slvp, 0)<0 && kill(0,$slvp)>0 && threads->self->tid == $thrid) {
+	alarm 0;
+	return;
+    }
     print "\nrun=0\n";
     exit 0;
 }
@@ -83,7 +91,6 @@ sub normal_exit{
 $SIG{PIPE}=\&normal_exit;
 $SIG{ALRM}=\&shut;
 
-my $queue:shared ="";
 
 sub ifilt{
     if($v{pause} || !$v{play}) {
@@ -112,13 +119,15 @@ sub ifilt{
     }
 }
 
-sub ofilt_alarm{ #child is hang
+sub ofilt_quit{ #child is hang
+    $SIG{ALRM}=\&shut;
     kill ALRM, $ifilt;
 }
 
 sub ofilt{
     local $s;
-    local $SIG{ALRM}=\&ofilt_alarm;    alarm $v{timeout};
+    local $SIG{ALRM}=\&ofilt_quit;
+    alarm $v{timeout};
     $s="";
     print "run=1\n";
     do {
@@ -143,7 +152,8 @@ sub ofilt{
 	}
       }
     }while($restart && !$shutstate && $restart && &$restart);
-    ofilt_alarm() unless $shutstate;
+    ofilt_quit() unless $SIG{ALRM} eq \&shut;;
+    normal_exit();
 }
 sub runslv{
     $slvp = open2(*SLVR, *SLVW, "exec @_ 2>&1");
@@ -216,7 +226,7 @@ while (<>){
 	    runslv $cmd;
 	}
 	$ifilt=$$;
-	$thr = threads->new(\&ofilt);
+	$thrid = threads->new(\&ofilt)->tid;
 	ifilt();
 	normal_exit();
     }elsif("$_" eq "run=0"){
